timerelationtools.timespan_2_starts_after_timespan_1_stops
==========================================================

.. autofunction:: abjad.tools.timerelationtools.timespan_2_starts_after_timespan_1_stops.timespan_2_starts_after_timespan_1_stops
